@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -33,7 +33,7 @@ namespace tgui
 
     BackendTextureSFML::BackendTextureSFML()
     {
-        m_isSmooth = false; // Smooth filter is disabled by default in SFML textures
+        m_isSmooth = m_texture.isSmooth(); // Smooth filter is disabled by default in SFML textures
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
