@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -28,9 +28,7 @@
 
 #include <TGUI/extlibs/IncludeSDL.hpp>
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Timer.hpp>
 #endif
 
@@ -284,7 +282,10 @@ namespace tgui
                     eventTGUI.mouseWheel.delta = static_cast<float>(eventSDL.wheel.y);
 #endif
 
-#if (SDL_MAJOR_VERSION > 2) || ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION >= 26))
+#if (SDL_MAJOR_VERSION >= 3)
+                eventTGUI.mouseWheel.x = static_cast<int>(eventSDL.wheel.mouse_x * m_dpiScale);
+                eventTGUI.mouseWheel.y = static_cast<int>(eventSDL.wheel.mouse_y * m_dpiScale);
+#elif (SDL_MAJOR_VERSION > 2) || ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION >= 26))
                 eventTGUI.mouseWheel.x = static_cast<int>(eventSDL.wheel.mouseX * m_dpiScale);
                 eventTGUI.mouseWheel.y = static_cast<int>(eventSDL.wheel.mouseY * m_dpiScale);
 #else
@@ -347,8 +348,13 @@ namespace tgui
 
                 // Remember which finger this is, for when we receive SDL_EVENT_FINGER_MOTION and SDL_EVENT_FINGER_UP events
                 m_touchFirstFingerDown = true;
+#if (SDL_MAJOR_VERSION >= 3)
+                m_touchFirstFingerId = eventSDL.tfinger.fingerID;
+                m_touchFirstFingerTouchId = eventSDL.tfinger.touchID;
+#else
                 m_touchFirstFingerId = eventSDL.tfinger.fingerId;
                 m_touchFirstFingerTouchId = eventSDL.tfinger.touchId;
+#endif
 
                 // Simulate a MouseButtonPressed event
                 eventTGUI.type = Event::Type::MouseButtonPressed;
@@ -360,9 +366,13 @@ namespace tgui
             case SDL_EVENT_FINGER_UP:
             {
                 // Only handle the event if this is the first finger
+#if (SDL_MAJOR_VERSION >= 3)
+                if (!m_touchFirstFingerDown || (m_touchFirstFingerId != eventSDL.tfinger.fingerID) || (m_touchFirstFingerTouchId != eventSDL.tfinger.touchID))
+                    return false;
+#else
                 if (!m_touchFirstFingerDown || (m_touchFirstFingerId != eventSDL.tfinger.fingerId) || (m_touchFirstFingerTouchId != eventSDL.tfinger.touchId))
                     return false;
-
+#endif
                 m_touchFirstFingerDown = false;
 
                 // Simulate a MouseButtonReleased event
@@ -375,8 +385,13 @@ namespace tgui
             case SDL_EVENT_FINGER_MOTION:
             {
                 // Only handle the event if this is the first finger
+#if (SDL_MAJOR_VERSION >= 3)
+                if (!m_touchFirstFingerDown || (m_touchFirstFingerId != eventSDL.tfinger.fingerID) || (m_touchFirstFingerTouchId != eventSDL.tfinger.touchID))
+                    return false;
+#else
                 if (!m_touchFirstFingerDown || (m_touchFirstFingerId != eventSDL.tfinger.fingerId) || (m_touchFirstFingerTouchId != eventSDL.tfinger.touchId))
                     return false;
+#endif
 
                 // Simulate a MouseMoved event
                 eventTGUI.type = Event::Type::MouseMoved;
@@ -398,7 +413,11 @@ namespace tgui
         {
             const bool wasScrolling = m_twoFingerScroll.isScrolling();
 
+#if (SDL_MAJOR_VERSION >= 3)
+            const auto fingerId = static_cast<std::intptr_t>(sdlEvent.tfinger.fingerID);
+#else
             const auto fingerId = static_cast<std::intptr_t>(sdlEvent.tfinger.fingerId);
+#endif
             const float x = sdlEvent.tfinger.x * m_framebufferSize.x;
             const float y = sdlEvent.tfinger.y * m_framebufferSize.y;
 
@@ -432,7 +451,7 @@ namespace tgui
 
         // If a text event consists of multiple unicode characters (which can happen when an IME is used) then our
         // converted event only contains the last character. We will send all other unicode characters here.
-        if ((event.type == Event::Type::TextEntered) && (sdlEvent.type == SDL_EVENT_TEXT_INPUT) && (sdlEvent.text.text[1] != '\0'))
+        if ((event.type == Event::Type::TextEntered) && (sdlEvent.type == SDL_EVENT_TEXT_INPUT) && (sdlEvent.text.text[0] != '\0') && (sdlEvent.text.text[1] != '\0'))
         {
             // Note that we also pass here if sdlEvent.text.text consists of multiple UTF-8 characters that still fit
             // within a single UTF-32 codepoint. So we still need to check that there are multiple UTF-32 codepoints below.
