@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -31,9 +31,7 @@
 #endif
 
 #include <TGUI/extlibs/IncludeSDL.hpp>
-#if SDL_MAJOR_VERSION >= 3
-    #include <SDL3/SDL_syswm.h>
-#else
+#if SDL_MAJOR_VERSION < 3
     #include <SDL_syswm.h>
 #endif
 
@@ -45,7 +43,7 @@
     #pragma warning(pop)
 #endif
 
-#if defined(TGUI_SYSTEM_LINUX) && defined(TGUI_USE_X11) && defined(SDL_ENABLE_SYSWM_X11)
+#if defined(TGUI_SYSTEM_LINUX) && defined(TGUI_USE_X11) && ((SDL_MAJOR_VERSION >= 3) || defined(SDL_VIDEO_DRIVER_X11))
     #include <X11/Xlib.h>
     #include <X11/cursorfont.h>
 #endif
@@ -352,21 +350,8 @@ namespace tgui
 
     void BackendSDL::updateMouseCursorStyle(Cursor::Type type, SDL_Cursor* cursor)
     {
-#ifdef TGUI_SYSTEM_WINDOWS
-        // Make sure the old cursor isn't still being used before we destroy it
-        bool cursorInUse = false;
-        for (auto& pair : m_guiResources)
-        {
-            if (pair.second.mouseCursor == type)
-                cursorInUse = true;
-        }
-        if (cursorInUse)
-            SetCursor(static_cast<HCURSOR>(LoadImage(nullptr, IDC_ARROW, IMAGE_CURSOR, 0, 0, LR_SHARED)));
-#endif
-
-        if (m_mouseCursors[type])
-            SDL_DestroyCursor(m_mouseCursors[type]);
-
+        // If a cursor already existed, then wait before destroying it until it is no longer in use
+        SDL_Cursor* oldCursor = m_mouseCursors[type];
         m_mouseCursors[type] = cursor;
 
         // Update the cursor on the screen if the cursor was in use
@@ -378,6 +363,9 @@ namespace tgui
                     updateShownMouseCursor(pair.second.window, type);
             }
         }
+
+        if (oldCursor)
+            SDL_DestroyCursor(oldCursor);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -391,7 +379,7 @@ namespace tgui
         // As of SDL 2.24, it uses an arrow pointing NW or NE. This is already much better, even though the arrow points on the wrong direction
         // for bottom corners. Having two-sided arrows for horizontal/vertical, but having a direction arrow for diagonal looks out of place though.
         // So we will continue to bypass SDL and use directional arrows in all directions.
-#if defined(TGUI_SYSTEM_LINUX) && defined(TGUI_USE_X11) && defined(SDL_ENABLE_SYSWM_X11)
+#if defined(TGUI_SYSTEM_LINUX) && defined(TGUI_USE_X11) && ((SDL_MAJOR_VERSION >= 3) || defined(SDL_VIDEO_DRIVER_X11))
         if ((type == Cursor::Type::SizeLeft) || (type == Cursor::Type::SizeRight)
             || (type == Cursor::Type::SizeTop) || (type == Cursor::Type::SizeBottom)
             || (type == Cursor::Type::SizeBottomRight) || (type == Cursor::Type::SizeTopLeft)
@@ -399,16 +387,24 @@ namespace tgui
         {
             if (!m_mouseCursors[type]) // Only bypass SDL when system cursors are used
             {
-                SDL_SysWMinfo sysInfo;
 #if SDL_MAJOR_VERSION >= 3
-                if (SDL_GetWindowWMInfo(window, &sysInfo, SDL_SYSWM_CURRENT_VERSION) && (sysInfo.subsystem == SDL_SYSWM_X11) && sysInfo.info.x11.display)
+                const SDL_PropertiesID windowProps = SDL_GetWindowProperties(window);
+                const Window windowX11 = static_cast<Window>(SDL_GetNumberProperty(windowProps, "SDL.window.x11.window", 0));
+                Display* displayX11 = reinterpret_cast<Display*>(SDL_GetProperty(windowProps, "SDL.window.x11.display", nullptr));
 #else
-                SDL_VERSION(&sysInfo.version); // We must fill in the version before calling SDL_GetWindowWMInfo
-                if (SDL_GetWindowWMInfo(window, &sysInfo) && (sysInfo.subsystem == SDL_SYSWM_X11) && sysInfo.info.x11.display)
-#endif
-                {
-                    auto* displayX11 = sysInfo.info.x11.display;
+                Display* displayX11 = nullptr;
+                Window windowX11 = 0;
 
+                SDL_SysWMinfo sysInfo;
+                SDL_VERSION(&sysInfo.version); // We must fill in the version before calling SDL_GetWindowWMInfo
+                if (SDL_GetWindowWMInfo(window, &sysInfo) && (sysInfo.subsystem == SDL_SYSWM_X11))
+                {
+                    displayX11 = sysInfo.info.x11.display;
+                    windowX11 = sysInfo.info.x11.window;
+                }
+#endif
+                if (displayX11)
+                {
                     unsigned int shapeX11;
                     if (type == Cursor::Type::SizeLeft)
                         shapeX11 = XC_left_side;
@@ -430,7 +426,7 @@ namespace tgui
                     auto cursorX11 = XCreateFontCursor(displayX11, shapeX11);
                     if (cursorX11 != None)
                     {
-                        XDefineCursor(displayX11, sysInfo.info.x11.window, cursorX11);
+                        XDefineCursor(displayX11, windowX11, cursorX11);
                         XFreeCursor(displayX11, cursorX11);
                     }
 
