@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -352,8 +352,13 @@ namespace tgui
             }
             case sf::Event::MouseWheelScrolled:
             {
+#if SFML_VERSION_MAJOR >= 3
+                if (eventSFML.mouseWheelScroll.wheel != sf::Mouse::Wheel::Vertical)
+                    return false; // TGUI only handles the vertical mouse wheel
+#else
                 if (eventSFML.mouseWheelScroll.wheel != sf::Mouse::Wheel::VerticalWheel)
                     return false; // TGUI only handles the vertical mouse wheel
+#endif
 
                 eventTGUI.type = Event::Type::MouseWheelScrolled;
                 eventTGUI.mouseWheel.delta = eventSFML.mouseWheelScroll.delta;
