@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,9 +22,8 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
-#include <TGUI/DefaultBackendWindow.hpp>
-
+// Imports need to be first when building as a module.
+// Config.hpp will already be included in the global section that is placed before this file.
 #if TGUI_BUILD_AS_CXX_MODULE
     #if TGUI_HAS_BACKEND_SFML_GRAPHICS
         import tgui.backend.sfml_graphics;
@@ -54,7 +53,11 @@
             import tgui.backend.glfw_gles2;
         #endif
     #endif
-#else
+#endif
+
+#include <TGUI/DefaultBackendWindow.hpp>
+
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Loading/ImageLoader.hpp>
     #include <TGUI/Backend/Window/BackendGui.hpp>
     #include <TGUI/Event.hpp>
@@ -108,7 +111,7 @@ namespace tgui
 #endif
 
 #if SFML_VERSION_MAJOR >= 3
-            m_window.create(sf::VideoMode{{width, height}}, title.toStdString(), sf::Style::Default, settings);
+            m_window.create(sf::VideoMode{{width, height}}, title.toStdString(), sf::Style::Default, sf::State::Windowed, settings);
 #else
             m_window.create(sf::VideoMode{width, height}, title.toStdString(), sf::Style::Default, settings);
 #endif
