@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -48,8 +48,8 @@ namespace tgui
 
     void SubwidgetContainer::setFocused(bool focused)
     {
-        m_container->setFocused(focused);
         Widget::setFocused(focused);
+        m_container->setFocused(m_focused);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -226,11 +226,15 @@ namespace tgui
 
         Widget::rendererChanged(property);
 
-        // Make sure to pass on the SubwidgetContainer's font to the internal container
+        // Make sure to pass on the SubwidgetContainer's font, opacity and text size to the internal container
         if (property == U"Font")
         {
             m_container->setInheritedFont(m_fontCached);
         }
+        else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
+        {
+            m_container->setInheritedOpacity(m_opacityCached);
+        }
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -325,6 +329,7 @@ namespace tgui
 
     bool SubwidgetContainer::updateTime(Duration elapsedTime)
     {
+        Widget::updateTime(elapsedTime);
         return m_container->updateTime(elapsedTime);
     }
 
