@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -743,8 +743,6 @@ namespace tgui
 
     void Widget::showWithEffect(ShowEffectType type, Duration duration)
     {
-        setVisible(true);
-
         // We store the state the widget is currently in. In the event another animation was already playing, we should try to
         // use the current state to start our animation at, but this is not the state that the widget should end at. We must
         // get this state BEFORE finishing the previous animation which is done by finishExistingConflictingAnimations.
@@ -754,6 +752,9 @@ namespace tgui
 
         finishExistingConflictingAnimations(m_showAnimations, type);
 
+        // Show the widget AFTER finishing existing animations, as finishing a hide animation would leave the widget invisible
+        setVisible(true);
+
         switch (type)
         {
             case ShowEffectType::Fade:
@@ -1054,7 +1055,8 @@ namespace tgui
                 if (m_parent)
                     m_parent->childWidgetFocused(shared_from_this());
 
-                onFocus.emit(this);
+                if (m_focused) // Might be altered by childWidgetFocused if the parent is disabled
+                    onFocus.emit(this);
             }
         }
         else // Unfocusing widget
