@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -169,7 +169,11 @@ namespace tgui
 
     void RadioButton::setText(const String& text)
     {
+        if (m_text.getString() == text)
+            return;
+
         m_text.setString(text);
+        onSizeChange.emit(this, getSize());
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
