@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -291,7 +291,11 @@ TEST_CASE("[Backend events]")
             {
                 sf::Event eventSFML;
                 eventSFML.type = sf::Event::MouseWheelScrolled;
+#if SFML_VERSION_MAJOR >= 3
+                eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::Vertical;
+#else
                 eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::VerticalWheel;
+#endif
                 eventSFML.mouseWheelScroll.delta = 2;
                 eventSFML.mouseWheelScroll.x = 200;
                 eventSFML.mouseWheelScroll.y = 150;
@@ -304,7 +308,11 @@ TEST_CASE("[Backend events]")
                 REQUIRE(eventTGUI.mouseWheel.y == 150);
 
                 // We only handle vertical scrolling
+#if SFML_VERSION_MAJOR >= 3
+                eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::Horizontal;
+#else
                 eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::HorizontalWheel;
+#endif
                 REQUIRE(!backendGuiSFML->convertEvent(eventSFML, eventTGUI));
             }
 
@@ -332,7 +340,11 @@ TEST_CASE("[Backend events]")
                 REQUIRE(eventTGUI.mouseButton.button == tgui::Event::MouseButton::Middle);
 
                 // Only left, middle and right mouse buttons are handled
+#if SFML_VERSION_MAJOR >= 3
+                eventSFML.mouseButton.button = sf::Mouse::Button::Extra1;
+#else
                 eventSFML.mouseButton.button = sf::Mouse::Button::XButton1;
+#endif
                 REQUIRE(!backendGuiSFML->convertEvent(eventSFML, eventTGUI));
             }
 
@@ -360,7 +372,11 @@ TEST_CASE("[Backend events]")
                 REQUIRE(eventTGUI.mouseButton.button == tgui::Event::MouseButton::Middle);
 
                 // Only left, middle and right mouse buttons are handled
+#if SFML_VERSION_MAJOR >= 3
+                eventSFML.mouseButton.button = sf::Mouse::Button::Extra1;
+#else
                 eventSFML.mouseButton.button = sf::Mouse::Button::XButton1;
+#endif
                 REQUIRE(!backendGuiSFML->convertEvent(eventSFML, eventTGUI));
             }
 
@@ -481,7 +497,11 @@ TEST_CASE("[Backend events]")
 
                 // Scroll the mouse wheel on top of the slider and verify that its value changes
                 eventSFML.type = sf::Event::MouseWheelScrolled;
+#if SFML_VERSION_MAJOR >= 3
+                eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::Vertical;
+#else
                 eventSFML.mouseWheelScroll.wheel = sf::Mouse::Wheel::VerticalWheel;
+#endif
                 eventSFML.mouseWheelScroll.delta = 4;
                 eventSFML.mouseWheelScroll.x = 260;
                 eventSFML.mouseWheelScroll.y = 80;
@@ -774,11 +794,20 @@ TEST_CASE("[Backend events]")
             {
                 SDL_Event eventSDL;
                 eventSDL.type = SDL_EVENT_TEXT_INPUT;
+#if SDL_MAJOR_VERSION >= 3
+                char textInput[4] = {
+                    static_cast<char>(static_cast<unsigned char>(0xE2)),
+                    static_cast<char>(static_cast<unsigned char>(0x9C)),
+                    static_cast<char>(static_cast<unsigned char>(0x85)),
+                    '\0'
+                };
+                eventSDL.text.text = textInput;
+#else
                 eventSDL.text.text[0] = static_cast<char>(static_cast<unsigned char>(0xE2));
                 eventSDL.text.text[1] = static_cast<char>(static_cast<unsigned char>(0x9C));
                 eventSDL.text.text[2] = static_cast<char>(static_cast<unsigned char>(0x85));
                 eventSDL.text.text[3] = '\0';
-
+#endif
                 tgui::Event eventTGUI;
                 REQUIRE(backendGuiSDL->convertEvent(eventSDL, eventTGUI));
                 REQUIRE(eventTGUI.type == tgui::Event::Type::TextEntered);
@@ -789,16 +818,19 @@ TEST_CASE("[Backend events]")
             {
                 SDL_Event eventSDL;
 
-#if ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION < 26))
+#if SDL_MAJOR_VERSION >= 3
+                eventSDL.wheel.mouse_x = 200;
+                eventSDL.wheel.mouse_y = 150;
+#elif ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION >= 26))
+                eventSDL.wheel.mouseX = 200;
+                eventSDL.wheel.mouseY = 150;
+#else
                 // SDL < 2.26 had no mouse position in its mouse scroll event, so first simulate a mouse move
                 eventSDL.type = SDL_MOUSEMOTION;
                 eventSDL.motion.which = 1;
                 eventSDL.motion.x = 200;
                 eventSDL.motion.y = 150;
                 backendGuiSDL->handleEvent(eventSDL);
-#else
-                eventSDL.wheel.mouseX = 200;
-                eventSDL.wheel.mouseY = 150;
 #endif
 
                 eventSDL.type = SDL_EVENT_MOUSE_WHEEL;
@@ -914,8 +946,13 @@ TEST_CASE("[Backend events]")
 
                 SDL_Event eventSDL;
                 eventSDL.type = SDL_EVENT_FINGER_DOWN;
+#if SDL_MAJOR_VERSION >= 3
+                eventSDL.tfinger.touchID = 1;
+                eventSDL.tfinger.fingerID = 1;
+#else
                 eventSDL.tfinger.touchId = 1;
                 eventSDL.tfinger.fingerId = 1;
+#endif
                 eventSDL.tfinger.x = 200.f / windowSize.x;
                 eventSDL.tfinger.y = 150.f / windowSize.y;
 
@@ -998,6 +1035,15 @@ TEST_CASE("[Backend events]")
                 // Type 3 characters in the edit box
                 SDL_Event eventSDL;
                 eventSDL.type = SDL_EVENT_TEXT_INPUT;
+#if SDL_MAJOR_VERSION >= 3
+                char textInput[2] = "A";
+                eventSDL.text.text = textInput;
+                backendGuiSDL->handleEvent(eventSDL);
+                textInput[0] = 'B';
+                backendGuiSDL->handleEvent(eventSDL);
+                textInput[0] = 'C';
+                backendGuiSDL->handleEvent(eventSDL);
+#else
                 eventSDL.text.text[0] = 'A';
                 eventSDL.text.text[1] = 0;
                 backendGuiSDL->handleEvent(eventSDL);
@@ -1005,7 +1051,7 @@ TEST_CASE("[Backend events]")
                 backendGuiSDL->handleEvent(eventSDL);
                 eventSDL.text.text[0] = 'C';
                 backendGuiSDL->handleEvent(eventSDL);
-
+#endif
                 // Erase the second character from the edit box
                 eventSDL.type = SDL_EVENT_KEY_DOWN;
                 eventSDL.key.windowID = 0;
@@ -1022,15 +1068,18 @@ TEST_CASE("[Backend events]")
                 REQUIRE(editBox->getText() == "AC");
 
                 // Scroll the mouse wheel on top of the slider and verify that its value changes
-#if ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION < 26))
+#if SDL_MAJOR_VERSION >= 3
+                eventSDL.wheel.mouse_x = 260;
+                eventSDL.wheel.mouse_y = 80;
+#elif ((SDL_MAJOR_VERSION == 2) && (SDL_MINOR_VERSION >= 26))
+                eventSDL.wheel.mouseX = 260;
+                eventSDL.wheel.mouseY = 80;
+#else
                 eventSDL.type = SDL_MOUSEMOTION;
                 eventSDL.motion.which = 1;
                 eventSDL.motion.x = 260;
                 eventSDL.motion.y = 80;
                 backendGuiSDL->handleEvent(eventSDL);
-#else
-                eventSDL.wheel.mouseX = 260;
-                eventSDL.wheel.mouseY = 80;
 #endif
                 eventSDL.type = SDL_EVENT_MOUSE_WHEEL;
                 eventSDL.wheel.direction = SDL_MOUSEWHEEL_NORMAL;
@@ -1091,7 +1140,11 @@ TEST_CASE("[Backend events]")
                 // Note that the resizing ignores the position of the touch ended event
                 const tgui::Vector2f windowSize = backendGuiSDL->getViewport().getSize();
                 eventSDL.type = SDL_EVENT_FINGER_DOWN;
+#if SDL_MAJOR_VERSION >= 3
+                eventSDL.tfinger.touchID = 1;
+#else
                 eventSDL.tfinger.touchId = 1;
+#endif
                 eventSDL.tfinger.x = 100.f / windowSize.x;
                 eventSDL.tfinger.y = 260.f / windowSize.y;
                 backendGuiSDL->handleEvent(eventSDL);
