@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -647,5 +647,28 @@ TEST_CASE("[Widget]")
             editBox->setFocused(true);
             REQUIRE(!editBox->isFocused());
         }
+
+        SECTION("Widgets should not be focusable if their parent is disabled (https://github.com/texus/TGUI/issues/226)")
+        {
+            tgui::Panel::Ptr panel = tgui::Panel::create();
+            tgui::EditBox::Ptr editBox = tgui::EditBox::create();
+            panel->add(editBox);
+
+            editBox->setFocused(true);
+            REQUIRE(editBox->isFocused());
+
+            // No widget can be focused while the container is disabled
+            panel->setEnabled(false);
+            REQUIRE(!editBox->isFocused());
+            editBox->setFocused(true);
+            REQUIRE(!editBox->isFocused());
+
+            // If the container is enabled again, it still has no focused widgets
+            panel->setEnabled(true);
+            REQUIRE(!panel->isFocused());
+            REQUIRE(!editBox->isFocused());
+            editBox->setFocused(true);
+            REQUIRE(editBox->isFocused());
+        }
     }
 }
