@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,8 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/Config.hpp>
+#include <TGUI/Widgets/CanvasBase.hpp>
+
 #if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
     #include <SFML/Graphics/View.hpp>
     #include <SFML/Graphics/Sprite.hpp>
@@ -30,6 +31,23 @@
 
 #include "Tests.hpp"
 
+static void testCanvasCommon(tgui::CanvasBase::Ptr canvas)
+{
+    SECTION("Ignore mouse events")
+    {
+        REQUIRE(!canvas->isIgnoringMouseEvents());
+        canvas->ignoreMouseEvents(true);
+        REQUIRE(canvas->isIgnoringMouseEvents());
+        canvas->ignoreMouseEvents(false);
+        REQUIRE(!canvas->isIgnoringMouseEvents());
+    }
+
+    SECTION("canGainFocus")
+    {
+        REQUIRE(!canvas->canGainFocus());
+    }
+}
+
 #if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
 
 #if TGUI_BUILD_AS_CXX_MODULE
@@ -100,6 +118,8 @@ TEST_CASE("[CanvasSFML]")
             REQUIRE(internalRenderTexture == &canvas->getRenderTexture());
         }
 
+        testCanvasCommon(canvas);
+
         testWidgetRenderer(canvas->getRenderer());
 
         SECTION("Saving and loading from file")
@@ -193,6 +213,8 @@ TEST_CASE("[CanvasSDL]")
             REQUIRE(internalTextureTarget == canvas->getTextureTarget());
         }
 
+        testCanvasCommon(canvas);
+
         testWidgetRenderer(canvas->getRenderer());
 
         SECTION("Saving and loading from file")
@@ -232,6 +254,8 @@ TEST_CASE("[CanvasOpenGL3]")
             REQUIRE(canvas->getSize() == tgui::Vector2f(200, 100));
         }
 
+        testCanvasCommon(canvas);
+
         testWidgetRenderer(canvas->getRenderer());
 
         SECTION("Saving and loading from file")
@@ -271,6 +295,8 @@ TEST_CASE("[CanvasGLES2]")
             REQUIRE(canvas->getSize() == tgui::Vector2f(200, 100));
         }
 
+        testCanvasCommon(canvas);
+
         testWidgetRenderer(canvas->getRenderer());
 
         SECTION("Saving and loading from file")
